@@ -7,6 +7,8 @@ from webdriver_manager.chrome import ChromeDriverManager
 async def get_driver(custom_options=None, driver_path=None):
     chrome_options = Options()
     chrome_options.add_argument("--headless")
+    chrome_options.add_argument("--no-sandbox")
+    chrome_options.add_argument("--disable-gpu")
     chrome_options.add_argument("--test-type")
     chrome_options.add_argument("--disable-logging")
     chrome_options.add_argument('--ignore-certificate-errors')
